//  Giuseppe Vacanti (cosine science & computing bv)
//  April  8, 2003
// 
//   $Id: IppvStorage.cc,v 1.1 2003/05/06 08:53:04 gvacanti Exp $

#include<Observation.h>

// Two predicates used to compare Ippvs by name and name/value.
namespace {

    class Ippv_equal_name : public unary_function<OdfIngest::Ippv, bool> {
    public:
	explicit Ippv_equal_name(const OdfIngest::Ippv & i) :ippv_(i) {}
	explicit Ippv_equal_name(const std::string & n): ippv_(OdfIngest::Ippv(n, "no_value")) {}
	bool operator()(const OdfIngest::Ippv & t) { return ippv_.name() == t.name(); }
    private:
	OdfIngest::Ippv ippv_;
    };
    
    class Ippv_equal : public unary_function<OdfIngest::Ippv, bool> {
    public:
	explicit Ippv_equal(const OdfIngest::Ippv & i) :ippv_(i) {}
	bool operator()(const OdfIngest::Ippv & t) { return ippv_.name() == t.name()
							 && ippv_.value() == t.value(); }
    private:
	OdfIngest::Ippv ippv_;
    };
}


using namespace OdfIngest;



OdfIngest::IppvStorage::IppvStorage() {
}

const Ippvs & OdfIngest::IppvStorage::ippvs() const {
  return ippvs_;
}

Ippvs & OdfIngest::IppvStorage::ippvs() {
  return ippvs_;
}

bool OdfIngest::IppvStorage::remove_ippv(const std::string& name) {
  OdfIngest::Ippvs::iterator p = std::find_if(ippvs_.begin(),
					      ippvs_.end(),
					      Ippv_equal_name(name));
  if(p != ippvs_.end()){
    ippvs_.erase(p);
    return true;
  } else
    return false;
}

bool OdfIngest::IppvStorage::has_ippv(const std::string & name) const {
  OdfIngest::Ippvs::const_iterator p = std::find_if(ippvs_.begin(),
					      ippvs_.end(),
					      Ippv_equal_name(name));
  return !(p == ippvs_.end());
}


bool OdfIngest::IppvStorage::insert_ippv(const Ippv & i) {
  if(has_ippv(i.name()))
    return false;
  else
    ippvs_.push_back(i);
  return true;
}

Ippv OdfIngest::IppvStorage::get_ippv(const std::string & name) const {
  OdfIngest::Ippvs::const_iterator p = std::find_if(ippvs_.begin(),
						    ippvs_.end(),
						    Ippv_equal_name(name));
  if(p == ippvs_.end())
    errstr << "The housekeeping parameter " << name << " does not exist."
	   << Sas::error("HousekeepingParameterDoesNotExist");
  return (*p);
}
