//  Giuseppe Vacanti (cosine science & computing bv)
//  January  7, 2003
// 
//   $Id: OdfDataSet.cc,v 1.1 2003/05/06 08:53:04 gvacanti Exp $
//

#include<Observation.h>

#include<SmartDal>

void OdfIngest::OdfDataSet::init_time() {
  if(format() == OdfSet::FITS){
    using namespace SmartDal;
    DataSetH set = open_set(name(), Read, Low);
    
    // Access by number as some ODF components may not have block
    // names. Also the block names encode the block number ...
    
    BlockH blk = set->block(0); 
    if(blk->hasAttribute("DATE-OBS")){
      std::string s = blk->attribute("DATE-OBS")->asString();
      if(STime::isValidTime(s)){
	start_.second = true;
	start_.first = STime(s);
      }
    }
	
    if(blk->hasAttribute("DATE-END")){
      std::string s = blk->attribute("DATE-END")->asString();
      if(STime::isValidTime(s)){
	end_.second = true;
	end_.first = STime(s);
      }
    }
  }
}  

OdfIngest::OdfDataSet::OdfDataSet(const std::string & name)
  : OdfSet(name),
    start_(std::make_pair("now",false)),
    end_(std::make_pair("now",false))    
{ init_time(); }

OdfIngest::OdfDataSet::OdfDataSet(const OdfSet & odfset)
  :
  OdfSet(odfset),
  start_(std::make_pair("now",false)),
  end_(std::make_pair("now",false))
{ init_time(); }

std::string OdfIngest::OdfDataSet::exposure_identifier() const {
  return basename().substr(16,6);
}

const STime & OdfIngest::OdfDataSet::start() const throw(HasNoTime) {
  if(!start_.second)
    throw HasNoTime();
  return start_.first;
}

const STime & OdfIngest::OdfDataSet::end() const throw(HasNoTime) {
  if(!end_.second)
    throw HasNoTime();
  return end_.first;
}

bool  OdfIngest::OdfDataSet::has_time() const {
  return start_.second && end_.second;
}

OdfIngest::OdfDataSet::ScheduledStatus OdfIngest::OdfDataSet::scheduled_status() const {
  char flag = basename()[18];
  ScheduledStatus ss = OdfDataSet::NotApplicable;
  switch(flag) {
  case 'X':
    ss = OdfDataSet::NotApplicable;
    break;
  case 'S':
    ss = OdfDataSet::Scheduled;
    break;
  case 'U':
    ss = OdfDataSet::Unscheduled;
    break;
    // FIXME
  default: {}
  }
  return ss;
}

ostream & OdfIngest::operator<<(ostream & os, const OdfDataSet & ds)
{
  os << ds.basename();
  return os;
}
