//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// August 2001
//

#include <Observation.h>
#include <OalServer.h>

#include <iostream>
#include <algorithm>

void Print_Instrument(const OdfIngest::Instrument & i) {
  std::cout << i.nickname() << std::endl;
}

void Print_DataSet(const OdfIngest::DataSet & s) {
  std::cout << s.basename() << std::endl;
}

void Print_Ippv(const OdfIngest::Ippv & i) {
  std::cout << i.name() << " = " << i.value() << std::endl;
}

void Print_Exposure(const OdfIngest::Exposure & e) {
  std::cout << e.counter() << " " << e.start_time().toString(0)
	    << " " << e.end_time().toString(0) << std::endl;
  std::for_each(e.ippvs().begin(), e.ippvs().end(), Print_Ippv);

}

void Print_Proposal(const ProposalInfo & pi) {
    std::cout 
      << pi.GoName << std::endl
      << pi.GoInstitute << std::endl
      << pi.GoAddress << std::endl
      << std::endl
      << std::endl
      << std::endl
      << std::endl
      << std::endl
      
      << pi.GoEmail << std::endl
      << pi.AO << std::endl
      << pi.scienceType << std::endl
      << pi.targetName << std::endl
      << pi.targetRa/15. << std::endl
      << pi.targetDec << std::endl
      << pi.obsDuration << std::endl
      << std::endl
      << pi.boresightRa/15. << std::endl
      << pi.boresightDec << std::endl
      << pi.posAngleConstLo << std::endl
      << pi.posAngleConstHi << std::endl
      << pi.posAngleOrigRef << std::endl
      << pi.emos1Prio << std::endl
      << pi.emos2Prio << std::endl
      << pi.epnPrio << std::endl
      << pi.rgs1Prio << std::endl
      << pi.rgs2Prio << std::endl
      << pi.omPrio << std::endl;
}

int main() {

  OdfIngest::Observation obs(oalServer.odf());
  
  std::cout << obs.directory() << std::endl
	    << obs.identifier() << " " << obs.revolution() << std::endl
	    << obs.start_time().toString(0) << " "
	    << obs.end_time().toString(0) << std::endl;

  std::for_each(obs.instruments().begin(), obs.instruments().end(),
		Print_Instrument);

  std::for_each(obs.sets().begin(), obs.sets().end(),
		Print_DataSet);

  std::for_each(obs.exposures().begin(), obs.exposures().end(),
		Print_Exposure);

  Print_Proposal(obs.proposal());

  //

  std::cout << "Observation Two" << std::endl;
  OdfIngest::Observation obs2(oalServer.odf()->directoryName());
  
  std::for_each(obs2.exposures().begin(), obs2.exposures().end(),
		Print_Exposure);


}
    

