//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// June 2000
//
#ifndef IPPVEXTRACTOR_H
#define IPPVEXTRACTOR_H

#include <iostream>
#include <vector>
#include <Xmm.h>
#include "Ippv.h"

// The IPPV extractor takes a list if IPPVs for the same instrument,
// reads them from the corresponding ODF datasets, and writes them out.

class IppvExtractor {
 public:
  virtual ~IppvExtractor() {};
  virtual unsigned ippvs() const = 0;
  virtual void write(ostream& o,
		     const STime& start,
		     const STime& stop) const = 0;
  virtual void document(ostream& o) const = 0;

  virtual Xmm::Instrument instrument() const = 0;

  // SCR117  
  virtual map<string,string> values(const STime& start,
				     const STime& stop) const = 0;

};

// This is the factory, where we indicate what instrument the IPPVs
// refer to and where on disk are the ODF datasets to be found.

class IppvExtractorServer {
 public:
  IppvExtractorServer();
  ~IppvExtractorServer();
  IppvExtractor * extractor(Xmm::Instrument,
			    const string& directory = ".",
			    const string& label = "");
};

#endif
